@@ -185,21 +185,25 @@ class AjaxTest(ViewTest):
     def request(self, path, view, data={},
                 credentials = None, arguments = {}):
         view = view[0] if hasattr(view,'__iter__') else view
-        return super(AjaxTest, self).request(path, view, data,
-                    True, credentials, arguments)
+        json_response_string = super(AjaxTest, self).request(path, view, data,
+                                                True, credentials, arguments) 
+        return simplejson.loads(json_response_string)
 
-    def verify_dajax_response(self, json_response_string, dajax_data):
-        json_response = simplejson.loads(json_response_string)
+    def verify_dajax_response(self, json_response, dajax_data, indexes=None):
         self.assertEqual(len(dajax_data), len(json_response))
-        for dajax, json in zip(dajax_data, json_response):
-            self.assertDictEqual(dajax, json)
+        if indexes is not None:
+            if indexes is True:
+                indexes = range(len(dajax_data))
+            for i, (dajax, json) in enumerate(zip(dajax_data, json_response)):
+                if i in indexes: 
+                    self.assertDictEqual(dajax, json)
 
     def request_response(self, path, view, data={},
                          credentials = None, arguments = {},
-                         dajax_data = []):
+                         dajax_data = [], indexes=None):
         response = self.request(path, view, data,
                                 credentials, arguments)
-        self.verify_dajax_response(response, dajax_data)
+        self.verify_dajax_response(response, dajax_data, indexes=indexes)
         return response
 
 class ModelsTest(TestCase):
